//  File: ConvertTemperatures.java
//  Enhanced version of temperature conversion
//  New components include Buttons and a Scrollbar.
// The Scrollbar and input box must work together
// Prepared by Dr. Spiegel

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

class ConvertTemperatures extends Frame
  implements ActionListener, WindowListener, AdjustmentListener

{ JLabel directions;
  JTextField fahrenheit;
  JLabel celsius;
  JScrollBar tempGuage;
  JButton Compute,Quit;


  ConvertTemperatures(String s)
  { // super() MUST be first
    super(s);

    // Need a JPanel to put things on
    JPanel F2C=new JPanel();
    F2C.setSize(300,200);

    // Set JFrame (this') size. Must do this, or only top bar will appear
    setSize(300,200);

    // setLayout(new FlowLayout());   No LayoutManager. Place items manually
    // Must set LayoutManager to be null to place items manually, however
    F2C.setLayout(null);

    // Need WindowListener to handle window close event
    addWindowListener(this);

    // Add Label for Directions
    directions = new JLabel("Enter temperature in Fahrenheit:");
    directions.setBounds(10,30,200,20);
    // Put Label on panel
    F2C.add(directions);

    // Add TextField for inputting temperatures
    fahrenheit = new JTextField(2);
    fahrenheit.setText("68");
    fahrenheit.setBounds(200,30,40,20);  // Set location in frame and size
    F2C.add(fahrenheit);
    fahrenheit.addActionListener(this);

    // Add a Scrollbar as an alternative input source. (Lots of events can happen...)
    tempGuage=new JScrollBar(JScrollBar.HORIZONTAL,68,1,-500,500);
    tempGuage.setLocation(5,400);
    tempGuage.setBounds(5,55,250,25);
    tempGuage.setUnitIncrement(1);
    tempGuage.setBlockIncrement(10);
    tempGuage.setVisibleAmount(1);
    F2C.add(tempGuage);
    tempGuage.addAdjustmentListener(this);

    // Add buttons to compute and quit
    Compute=new JButton("Compute!");
    Compute.setBounds(50,90,70,40);
    F2C.add(Compute);
    Compute.addActionListener(this);
    Quit=new JButton("Quit");
    Quit.setBounds(130,90,70,40);
    F2C.add(Quit);
    Quit.addActionListener(this);
    // Add label for reporting output
    celsius = new JLabel();
    celsius.setBounds(10,85,350,130);
    celsius.setFont(new Font("TimesRoman 12 point bold.", 20, 20));
    F2C.add(celsius);

    // Place the panel onto the frame
    add(F2C);
    setVisible(true);
  }

  public void windowClosed(WindowEvent event) {}
  public void windowDeiconified(WindowEvent event) {}
  public void windowIconified(WindowEvent event) {}
  public void windowActivated(WindowEvent event) {}
  public void windowDeactivated(WindowEvent event) {}
  public void windowOpened(WindowEvent event) {}
  public void windowClosing(WindowEvent event) { System.exit(0); }

  // Handle action events:
  //	TextField return pressed
  //	Button pushed
  public void actionPerformed(ActionEvent event)
  { int f = Integer.parseInt(fahrenheit.getText());
    // Set the Scrollbar to show the temperature in the TextField box
    tempGuage.setValue(f);
    if (event.getActionCommand()=="Compute!") {
	    	long c = Math.round(5.0*(f - 32)/9.0);
	    	celsius.setText(f + "\u00B0F = " + c + "\u00B0C");
    }
    else if (event.getActionCommand()=="Quit")
		System.exit(0);
    else   // Clear off the last result
		celsius.setText("                       ");
  }

  // Handle Adjustment events on the Scrollbar:
  //	Arrows, gray area or position indicator
  public void adjustmentValueChanged(AdjustmentEvent event)
  {if (event.getAdjustmentType()==event.UNIT_DECREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int decValue=tempGuage.getUnitIncrement();
		if (value-decValue>tempGuage.getMinimum())
			fahrenheit.setText(String.valueOf(value-decValue));
		else {
			tempGuage.setValue(tempGuage.getMinimum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.UNIT_INCREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int incValue=tempGuage.getUnitIncrement();
		if (value+incValue<tempGuage.getMaximum())
			fahrenheit.setText(String.valueOf(value+incValue));
		else {
			tempGuage.setValue(tempGuage.getMaximum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.BLOCK_DECREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int decValue=tempGuage.getBlockIncrement();
		if (value-decValue>tempGuage.getMinimum())
			fahrenheit.setText(String.valueOf(value-decValue));
		else {
			tempGuage.setValue(tempGuage.getMinimum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==event.BLOCK_INCREMENT) {
		int value=Integer.valueOf(fahrenheit.getText()).intValue();
		int incValue=tempGuage.getBlockIncrement();
		if (value+incValue<tempGuage.getMaximum())
			fahrenheit.setText(String.valueOf(value+incValue));
		else {
			tempGuage.setValue(tempGuage.getMaximum());
			fahrenheit.setText(String.valueOf(tempGuage.getValue()));
		}
   }
   else if (event.getAdjustmentType()==5)  // Adjusted scroll box
		fahrenheit.setText(String.valueOf(tempGuage.getValue()));
   tempGuage.setValue(Integer.valueOf(fahrenheit.getText()).intValue());
   celsius.setText("                                     ");
  }

}

class TestConvertTemperatures
{ public static void main(String[] args)
  { new ConvertTemperatures("Fahrenheit To Celsius Conversion");
  }
}
